@@ -237,10 +237,9 @@ hspell_provider_list_dicts (EnchantProvider * me,
 	if(dictionary_path && *dictionary_path && g_file_test (dictionary_path, G_FILE_TEST_EXISTS)) {
 		*out_n_dicts = 2;
 		
-		out_list = g_new0 (char *, 3);
+		out_list = g_new0 (char *, 2);
 		
-		out_list[0] = g_strdup ("he_IL");
-		out_list[1] = g_strdup ("he");
+		out_list[0] = g_strdup ("he");
 	}		
 		
 	return out_list;
@@ -266,13 +265,13 @@ hspell_provider_dispose (EnchantProvider * me)
 	g_free (me);
 }
 
-static char *
+static const char *
 hspell_provider_identify (EnchantProvider * me)
 {
 	return "hspell";
 }
 
-static char *
+static const char *
 hspell_provider_describe (EnchantProvider * me)
 {
 	return "Hspell Provider";
@@ -284,6 +283,9 @@ extern "C"
 #endif
 	
 ENCHANT_MODULE_EXPORT (EnchantProvider *) 
+	     init_enchant_provider (void);
+
+EnchantProvider *
 init_enchant_provider (void)
 {
 	EnchantProvider *provider;
